<template>
  <AuthLayout>
    <FormGroup @submit="submit">
      <AlertError v-if="form.errors && form.errors?.unknown">
        {{ form.errors.unknown }}
      </AlertError>
      <FormInput
        id="email"
        :errors="form.errors.email"
      >
        <FormLabel>{{ $t("app.auth.reset_password.form.email") }}</FormLabel>
        <FormText
          v-model="form.values.email"
          autocomplete="email"
          name="email"
          required
          type="email"
        />
      </FormInput>
      <FormInput
        id="password"
        :errors="form.errors.password"
      >
        <FormLabel>{{ $t("app.auth.reset_password.form.password") }}</FormLabel>
        <FormText
          v-model="form.values.password"
          autocomplete="new-password"
          name="password"
          required
          type="password"
        />
      </FormInput>
      <FormInput
        id="password_confirmation"
        :errors="form.errors.password_confirmation"
      >
        <FormLabel>{{ $t("app.auth.reset_password.form.password_confirmation") }}</FormLabel>
        <FormText
          v-model="form.values.password_confirmation"
          autocomplete="new-password"
          name="password_confirmation"
          required
          type="password"
        />
      </FormInput>
      <div>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-primary w-full"
        >
          {{ $t("app.auth.reset_password.form.submit") }}
        </FormSubmit>
      </div>
    </FormGroup>
  </AuthLayout>
</template>

<script lang="ts" setup>
import AuthLayout from "@/js/contexts/auth/ui/layouts/AuthLayout.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";
import useSnowflake from "@/js/contexts/shared/composables/useSnowflake";

const { t } = useI18n();
const route = useRoute();
const router = useRouter();
const { props } = useSnowflake();
const { successNotification } = useNotification();

useHead({
  title: t("app.auth.reset_password.title"),
});

const form = useForm({
  token: String(route.params?.token),
  email: "",
  password: "",
  password_confirmation: "",
});

const submit = () => {
  form.post("/reset-password", {
    onError: () => form.reset("password", "password_confirmation"),
    onSuccess: () => {
      successNotification(t("app.auth.reset_password.success"));
      router.push({ name: props.links.homepage ? "index" : "dashboard" });
    },
  });
};
</script>
